To install:
1. Download latest .whl from releases
2. Run (in console) "pip install PathToWhl.whl" (e.g. pip install C:/PythonWheels/rus_roulette-1.1.0-py3-none-any.whl)

To run in python:
1. Import (from rus_roulette import *)
2. Run roulette()
